mdd40k <- function(df0,pmix=0.5,sigmanoise=200,seed){
  if (missing(seed)) { 
    seed <- sample(10001, 1) - 1
    cat("\nSeed value =", seed, "\n")
  } 
  set.seed(seed)   # Set seed for Monte Carlo pseudo-random sequence...
  df0$untwycost <- pmix*df0$prwycost + (1-pmix)*df0$clrescost;
  df0$trtwycost <- df0$trtmfrac*df0$untwycost;
  df0$ltdcost <- round(df0$trtwycost - df0$untwycost, digits = 0);
  len <- length(df0$pslocal);
  df0$trtm <-rbinom(len,size=1,prob=df0$pslocal);
  df0$twyrcost <- ifelse(df0$trtm, df0$trtwycost, df0$untwycost);
  df0$wyrcost <- round(df0$twyrcost + as.vector(sigmanoise*rnorm(len)), digits = 0);
  df0$wyrcost <- ifelse(df0$wyrcost < 100, 100, df0$wyrcost);
  df0$wyrcost <- ifelse(df0$wyrcost > 50000, 50000, df0$wyrcost);
  return(df0);
}

mdd26 <- read.csv("E:/JSTP/mddsim/mddsim26.csv")  # Modify this line to read from the
                                                  # folder containing mddsim26.csv   
mdd <- mdd26[,1:20]	# Input (and output) files for the mdd40k() function should
                    # have 20 columns ...with the specified column names.

# We now demonstrate that a dataset output by mdd40k() can also be used as input. 

# The following call illustrates how the original data were generated.
# Note that default values of pmix and sigmanoise are used here.
mddsim <- mdd40k(mdd,seed=1249)
# write.csv(mddsim, file="E:/JSTP/mddsim/mddsim.csv", row.names = FALSE)

# This call illustrates generation of a different dataset.
mddsimX <- mdd40k(mdd,pmix=0.3,sigmanoise=500,seed=7777)
# write.csv(mddsimX, file="E:/JSTP/mddsim/mddsimX.csv", row.names = FALSE)
 
